==> kendo-layout-vue-wrapper-2020.3.915-dev.920.tgz: package/docs/contextmenu/index.md <==
---
title: Overview
page_title: ContextMenu Overview - Components - Kendo UI for Vue
description: "Get an overview of the features the Kendo UI ContextMenu wrapper for Vue delivers and use the component in Vue projects."
slug: overview_contextmenu
position: 1
---

# ContextMenu Overview

The ContextMenu displays hierarchical data as a multi-level menu in a popup.

You can define its items and initialize it with the wrapper, or use the API to add and remove its items. You can also specify a target for the ContextMenu along with a filter for multiple targets as well as an event which will trigger the popping up of the ContextMenu.

## Basic Usage

The following example demonstrates the ContextMenu in action.

```html-preview
<div id="vueapp" class="vue-app">
	<div id="target">Target</div>
	<kendo-contextmenu>
    <li>News
        <ul>
            <li>Sport</li>
            <li>Weather</li>
        </ul>
    </li>
    <li>Countries
        <ul>
            <li>Italy</li>
            <li>Spain</li>
            <li>Slovakia</li>
        </ul>
    </li>
	</kendo-contextmenu>
</div>
```
```js
    Vue.use(LayoutInstaller);
    new Vue({
        el: '#vueapp',
        target: "#target"
    })
```

## Functionality and Features

* [Scrollable ContextMenu]({% slug scrollable_contextmenu %})
* [Data binding]({% slug databinding_contextmenu %})

## Suggested Links

* [Kendo UI ContextMenu for jQuery](https://docs.telerik.com/kendo-ui/controls/navigation/menu/contextmenu)
* [API Reference of the ContextMenu Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/contextmenu)

==> kendo-layout-vue-wrapper-2024.1.319.tgz: package/docs/contextmenu/index.md <==
---
title: Overview
page_title: ContextMenu Overview - Components - Kendo UI for Vue
description: "Get an overview of the features the Kendo UI ContextMenu wrapper for Vue delivers and use the component in Vue projects."
slug: overview_contextmenu_wrapper
canonicalLink: "https://www.telerik.com/kendo-vue-ui/components/layout/menu/context-menu/"
position: 1
---

<div><WrapperBanner link="/kendo-vue-ui/components/layout/menu/context-menu"></WrapperBanner></div>    

# ContextMenu Overview

The ContextMenu displays hierarchical data as a multi-level menu in a popup.

You can define its items and initialize it with the wrapper, or use the API to add and remove its items. You can also specify a target for the ContextMenu along with a filter for multiple targets as well as an event which will trigger the popping up of the ContextMenu.

<div data-component="StartFreeTrialSection"></div>

## Basic Usage

The following example demonstrates the ContextMenu in action.

{% meta height:300 %}
{% embed_file contextmenu/basic/main.vue preview %}
{% embed_file contextmenu/basic/main.js %}
{% endmeta %}

## Functionality and Features

* [Scrollable ContextMenu]({% slug scrollable_contextmenu_wrapper %})
* [Data binding]({% slug databinding_contextmenu_wrapper %})

## Suggested Links

* [Kendo UI ContextMenu for jQuery](https://docs.telerik.com/kendo-ui/controls/navigation/menu/contextmenu)
* [API Reference of the ContextMenu Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/contextmenu)
